OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "Չը՛խկ",
    "Calendar" : "Օրացույց",
    "Today" : "Այսօր",
    "Day" : "Օր",
    "Week" : "Շաբաթ",
    "Month" : "Ամիս",
    "Download" : "Ներբեռնել",
    "Delete" : "Ջնջել",
    "Share link" : "Կիսվել հղմամբ",
    "Share with users or groups" : "Կիսվել օգտատերերի կամ խմբերի հետ",
    "can edit" : "կարող է խմբագրել",
    "Cancel" : "Չեղարկել",
    "Email" : "Էլ․փոստ",
    "Unknown" : "Անհայտ",
    "never" : "երբեք",
    "after" : "հետո",
    "Repeat" : "Կրկնել",
    "Monday" : "Երկուշաբթի",
    "More" : "Ավելի",
    "Save" : "Պահպանել",
    "Update" : "Թարմացնել",
    "Personal" : "Անձնական",
    "Details" : "Մանրամասներ",
    "Attendees" : "Մասնակիցներ",
    "Reminders" : "Հիշեցումներ",
    "Close" : "Փակել",
    "today" : "այսօր",
    "Location" : "Տեղակայություն",
    "Description" : "Նկարագրություն",
    "Confirmed" : "Հաստատված",
    "Mail" : "Փոստ",
    "Play" : "Նվագարկել",
    "Global" : "Ընդհանուր"
},
"nplurals=2; plural=(n != 1);");
